#
# spec file for package python-zeep
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-zeep
Version:        3.4.0
Release:        lp152.1.1
Summary:        A Python SOAP client based on lxml/requests
License:        MIT
Group:          Development/Languages/Python
URL:            http://docs.python-zeep.org
Source:         https://files.pythonhosted.org/packages/source/z/zeep/zeep-%{version}.tar.gz
Patch1:         pytest4.patch
Patch2:         pytest5.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-appdirs >= 1.4.0
Requires:       python-attrs >= 17.2.0
Requires:       python-cached-property >= 1.3.0
Requires:       python-defusedxml >= 0.4.1
Requires:       python-isodate >= 0.5.4
Requires:       python-lxml >= 3.1.0
Requires:       python-pytz
Requires:       python-requests >= 2.7.0
Requires:       python-requests-toolbelt >= 0.7.1
Requires:       python-six >= 1.9.0
Requires:       python-tornado >= 4.0.2
Requires:       python-xmlsec >= 0.6.1
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module appdirs >= 1.4.0}
BuildRequires:  %{python_module attrs >= 17.2.0}
BuildRequires:  %{python_module cached-property >= 1.3.0}
BuildRequires:  %{python_module defusedxml >= 0.4.1}
BuildRequires:  %{python_module freezegun >= 0.3.8}
BuildRequires:  %{python_module isodate >= 0.5.4}
BuildRequires:  %{python_module lxml >= 3.1.0}
BuildRequires:  %{python_module mock >= 2.0.0}
BuildRequires:  %{python_module pretend >= 1.0.8}
BuildRequires:  %{python_module pytest >= 3.1.3}
BuildRequires:  %{python_module pytest-tornado >= 0.4.5}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module requests >= 2.7.0}
BuildRequires:  %{python_module requests-mock >= 0.7.0}
BuildRequires:  %{python_module requests-toolbelt >= 0.7.1}
BuildRequires:  %{python_module six >= 1.9.0}
BuildRequires:  %{python_module tornado >= 4.0.2}
BuildRequires:  %{python_module xmlsec >= 0.6.1}
BuildRequires:  python3-aiohttp >= 1.0
BuildRequires:  python3-aioresponses >= 0.4.1
# /SECTION
%ifpython3
Requires:       python-aiohttp >= 1.0
%endif
%python_subpackages

%description
Python SOAP client based on python-lxml and python-requests

%prep
%setup -q -n zeep-%{version}
%autopatch -p1
# disable broken tests
rm tests/test_wsse_signature.py
rm tests/test_wsse_username.py
rm tests/test_wsse_utils.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
export PYTHONDONTWRITEBYTECODE=1
%pytest tests/

%files %{python_files}
%doc CHANGES README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Fri Nov  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patches to fix build with current pytests (From upstream PRs):
  * pytest4.patch
  * pytest5.patch
- Tweak the deps to stay resolvable
* Mon Aug 26 2019 Todd R <toddrme2178@gmail.com>
- Fix unit tests
- Use better way to handle tornado version compatibility.
* Mon Jul 29 2019 Todd R <toddrme2178@gmail.com>
- Don't allow python-tornado >= 5
* Fri Jun 14 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 3.4.0
  * Allow passing xsd.Nil to sequences
  * Add support for passing custom digest and signature methods during WSSE
    signing
  * Fix path resolving during XSD imports
* Mon Mar 25 2019 pgajdos@suse.com
- version update to 3.3.1
  * Fix issue with empty xsd:import statements on Python 2.7 (#930)
  * Extend the force_https flag to also force loading xsd files from https when
  a http url is encountered from a https domain
  * Fix handling recursive xsd imports when the url's are enforced from http to
  https.
  * Fix reference attribute when using the Binary Security Token (#873)
  * Add support for the WSAM namespace (#890)
* Tue Feb 26 2019 John Vandenberg <jayvdb@gmail.com>
- Remove from builds undesirable pytest plugins suited for development
- Add minimum build version for tornado
- Remove inappropriate runtime dependency on aioresponses
- Update to v3.2.0
  * Fix abstract message check for NoneType before attempting to access parts
  * Improve support for 'Chameleon' XSD schemas (#879, #888)
  * Fix resolving qualified references (#879)
  * Fix issue with duplicate soap:body tags when multiple parts used (#879)
  * Fix Choice with unbound Any element (#871)
  * Add xsd_ignore_sequence_order flag (#880)
  * Add support for timestamp token in WSS headers (#817)
  * Accept strings for xsd.DateTime (#886)
* Fri Dec  7 2018 Tomáš Chvátal <tchvatal@suse.com>
- Drop patch relax-python-requires.patch not really needed
- Try to check mtime issue on pyc files
  * caused by fdupes as it is linking equal file with diferent mtime
    while it should have no real impact on the package
* Tue Nov 27 2018 Jan Engelhardt <jengelh@inai.de>
- Trim time-sensitive wording of summary.
* Tue Nov 27 2018 Tomáš Chvátal <tchvatal@suse.com>
- Sort out with spec-cleaner
- Remove not needed devel dependency
* Mon Nov 26 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 3.1.0
- Add patch to relax Python version requirements in setup.py
  + relax-python-requires.patch
- Disable tests that are currently broken
  + tests/test_tornado_transport.py
  + tests/test_wsse_signature.py
  + tests/test_wsse_username.py
  + tests/test_wsse_utils.py
